#!/usr/bin/env python
import re
import argparse
import sys
import os
import numpy as np
import subprocess

"""
Split Yambo RPA calculations
"""

def exit_error(message):
        print(message)
        sys.exit(1)

#
# parse command line
#
parser = argparse.ArgumentParser(prog='split_rpa_yambo',description='Split RPA calculations with Yambo',epilog="Copyright Claudio Attaccalite 2016")
parser.add_argument('-f', help='original yambo RPA file' ,type=str,dest="ifilename")
parser.add_argument('-c', help='yambo command line' ,type=str,dest="yambocmd",default="yambo")
args = parser.parse_args()

if (args.ifilename == None ): exit_error('type "split_rpa_yambo.py --help" for help ')

try:
    yamboinput=open(args.ifilename,"r")
except:
    exit_error(" Error reading %s " % args.ifilename)

print("\n\n\n  Split Yambo RPA calculations \n")

lines=yamboinput.read()

pattern=r'\s*ETStpsXd\s*=\s*(\d*)'
try:
    match = re.search(pattern, lines, re.MULTILINE)
    ensteps = int(match.group(1))
except:
    exit_error("Error reading ensteps")

print("Number of energy steps : %s " % str(ensteps))

decimal  =r'-?\d+\.\d*|-?\.\d+'
EnRangePattern=r'\s*EnRngeXd\s*\n\s*('+decimal+')\s*\|\s*('+decimal+')\s*\|\s*eV'
try:
    match = re.search(EnRangePattern, lines, re.MULTILINE)
    if match:
        en1 = float(match.group(1))
        en2 = float(match.group(2))
except:
    exit_error("Error reading energy range")

print("Energy range : %s | %s | eV " % (str(en1),str(en2)))

for i in range(0,ensteps):
    print("\n Doing step %d of %d .... \n" %(i+1,ensteps))
    en=(en2-en1)*float(i)/float(ensteps-1.0)+en1
    OldPattern=r'ETStpsXd\s*=\s*(\d*)'
    NewPattern=r'ETStpsXd= 1'
    newlines=re.sub(OldPattern,NewPattern, lines, re.MULTILINE)
    OldPattern=r'% EnRngeXd\s*('+decimal+')\s*\|\s*('+decimal+')\s*\|\s*eV'
    NewPattern=r'%% EnRngeXd \n %10.6f | %10.6f | eV' % (en,en)
    newlines=re.sub(OldPattern,NewPattern, newlines, re.MULTILINE)

    inputfile="yambo_rpa_%d.in" % i
    ofile=open(inputfile,'w')
    ofile.write(newlines)
    ofile.close()


    cmdline=args.yambocmd+" -F "+inputfile+" -J RPA%d " % i
    try:
        status=subprocess.call(cmdline,shell=True)
    except:
        exit_error("Error running: " + cmdline + "\n")




    


